## START: Set by rpmautospec
## (rpmautospec version 0.7.3)
## RPMAUTOSPEC: autorelease, autochangelog
%define autorelease(e:s:pb:n) %{?-p:0.}%{lua:
    release_number = 2;
    base_release_number = tonumber(rpm.expand("%{?-b*}%{!?-b:1}"));
    print(release_number + base_release_number - 1);
}%{?-e:.%{-e*}}%{?-s:.%{-s*}}%{!?-n:%{?dist}}
## END: Set by rpmautospec

Name: pymol
Summary: PyMOL Molecular Graphics System
Version: 3.1.0
Release: %autorelease

# Which files use following license:
# BSD: main license of open source PyMOL and some plugins
# MIT: modules/pymol_web/examples/sample13/jquery.js
# Bitstream Vera: layer1/FontTTF.h
# OFL: layer1/FontTTF2.h
License: MIT-0 AND BSD AND Bitstream-Vera AND OFL-1.1
URL: http://www.pymol.org
Source0: https://github.com/schrodinger/pymol-open-source/archive/v%{version}/%{name}-open-source-%{version}.tar.gz
Source1: %{name}.png
Source2: %{name}.desktop
Source3: %{name}.appdata.xml

# https://bugzilla.redhat.com/show_bug.cgi?id=1311626
Patch1: %{name}-wmclass-main.patch
Patch2: %{name}-wmclass-pmgapp.patch
Patch3: %{name}-mmtf.patch

BuildRequires: desktop-file-utils
BuildRequires: libappstream-glib
BuildRequires: freetype-devel
BuildRequires: gcc
BuildRequires: gcc-c++
BuildRequires: glew-devel
BuildRequires: glm-devel
BuildRequires: libGL-devel
BuildRequires: libpng-devel
BuildRequires: libxml2-devel
BuildRequires: mmtf-cpp-devel
BuildRequires: msgpack-devel
BuildRequires: netcdf-devel
BuildRequires: catch2-devel
BuildRequires: pyproject-rpm-macros
BuildRequires: python3-devel
# pymol-3.1.0 exactly requires pytest-8.2.2 and pillow-10.3.0
BuildRequires: python3-pytest
BuildRequires: python3-pillow

# Qt interface
BuildRequires: python3-qt5-devel
BuildRequires: freeglut-devel

# Optional, will fall back to Tk interface if compiled with --glut
BuildRequires: python3-pyside6-devel

Requires: apbs%{?_isa}
Requires: chemical-mime-data

%py_provides PyMOL
%py_provides python3-%{name}

%description
PyMOL is a molecular graphics system with an embedded Python
interpreter designed for real-time visualization and rapid generation
of high-quality molecular graphics images and animations. It is fully
extensible and available free to everyone via the "Python"
license. Although a newcomer to the field, PyMOL can already be used
to generate stunning images and animations with ease. It can also
perform many other valuable tasks (such as editing PDB files) to
assist you in your research.

%package -n pymol+tests
Summary: Metapackage for PyMOL: tests
Requires: python3dist(pymol) = 0:3.1

%description -n pymol+tests
This is a metapackage contains PyMOL C-level tests.

%prep
%autosetup -n %{name}-open-source-%{version} -p1

ln -sr modules/web modules/%{name}_web

# Forcing numpy version
# https://github.com/schrodinger/pymol-open-source/pull/429
sed -e 's|1.26.4,<2|1.26.4,<3|g' -i ./pyproject.toml

%generate_buildrequires
%pyproject_buildrequires -p

%build
%pyproject_wheel -C=use-openmp=yes -C=testing=true -C=use-msgpackc=c++11

%install
%pyproject_install
%pyproject_save_files %{name} chempy web %{name}2 %{name}_web pmg_tk pmg_qt

cp -a testing %{buildroot}%{python3_sitearch}/%{name}/
%py3_shebang_fix %{buildroot}%{python3_sitearch}/%{name}/testing/modules/xmlrunner/tests/testsuite.py

# Create executable script for running PyMOL
echo "#!/bin/sh" > pymol
echo "export PYMOL_PATH=%{python3_sitearch}/%{name}" >> %{name}
echo "exec %{__python3} %{python3_sitearch}/%{name}/__init__.py \"\$@\"" >> %{name}

# icon2.svg is wanted outside pymol_path directory
mkdir -p %{buildroot}%{python3_sitearch}/%{name}/data/pymol/icons
touch %{buildroot}%{python3_sitearch}/%{name}/data/pymol/icons/icon2.svg
ln -sfr %{python3_sitearch}/%{name}/pymol_path/data/pymol/icons/icon2.svg %{buildroot}%{python3_sitearch}/%{name}/data/pymol/icons/icon2.svg
#

mkdir -p %{buildroot}%{_bindir}
install -p -m 755 %{name} %{buildroot}%{_bindir}/

desktop-file-install --vendor='' --dir=%{buildroot}%{_datadir}/applications %{SOURCE2}
mkdir -p %{buildroot}%{_datadir}/pixmaps
install -p -m 644 %{SOURCE1} %{buildroot}%{_datadir}/pixmaps/

mkdir -p %{buildroot}%{_metainfodir}
install -p -m 644 %{SOURCE3} %{buildroot}%{_metainfodir}/
appstream-util validate-relax --nonet %{buildroot}/%{_metainfodir}/*.appdata.xml

%check
%py3_check_import -t %{name} chempy web %{name}2 %{name}_web pmg_tk pmg_qt

%files -n %{name} -f %{pyproject_files}
%doc AUTHORS DEVELOPERS README.* ChangeLog
%{_bindir}/%{name}
%{_datadir}/applications/%{name}.desktop
%{_metainfodir}/%{name}.appdata.xml
%{_datadir}/pixmaps/%{name}.png
%{python3_sitearch}/%{name}/data/pymol/icons/

%files -n pymol+tests
%{python3_sitearch}/%{name}/testing/

%changelog
## START: Generated by rpmautospec
* Mon Feb 03 2025 Antonio Trande <sagitter@fedoraproject.org> - 3.1.0-2
- Add tests subpackage

* Sun Feb 02 2025 Antonio Trande <sagitter@fedoraproject.org> - 3.1.0-1
- Release 3.1.0 (rhbz#2274376) | Switch to newer python build method

* Sat Jan 18 2025 Fedora Release Engineering <releng@fedoraproject.org> - 3.0.0-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_42_Mass_Rebuild

* Wed Nov 13 2024 Antonio Trande <sagitter@fedoraproject.org> - 3.0.0-1
- Release 3.0.0

* Wed Sep 04 2024 Miroslav Suchý <msuchy@redhat.com> - 2.5.0-14
- convert license to SPDX

* Fri Jul 19 2024 Fedora Release Engineering <releng@fedoraproject.org> - 2.5.0-13
- Rebuilt for https://fedoraproject.org/wiki/Fedora_41_Mass_Rebuild

* Sat Jun 08 2024 Python Maint <python-maint@redhat.com> - 2.5.0-12
- Rebuilt for Python 3.13

* Fri Jan 26 2024 Fedora Release Engineering <releng@fedoraproject.org> - 2.5.0-11
- Rebuilt for https://fedoraproject.org/wiki/Fedora_40_Mass_Rebuild

* Sun Jan 21 2024 Fedora Release Engineering <releng@fedoraproject.org> - 2.5.0-10
- Rebuilt for https://fedoraproject.org/wiki/Fedora_40_Mass_Rebuild

* Fri Jul 21 2023 Fedora Release Engineering <releng@fedoraproject.org> - 2.5.0-9
- Rebuilt for https://fedoraproject.org/wiki/Fedora_39_Mass_Rebuild

* Fri Jun 16 2023 Python Maint <python-maint@redhat.com> - 2.5.0-8
- Rebuilt for Python 3.12

* Fri Jan 20 2023 Fedora Release Engineering <releng@fedoraproject.org> - 2.5.0-7
- Rebuilt for https://fedoraproject.org/wiki/Fedora_38_Mass_Rebuild

* Fri Jul 22 2022 Fedora Release Engineering <releng@fedoraproject.org> - 2.5.0-6
- Rebuilt for https://fedoraproject.org/wiki/Fedora_37_Mass_Rebuild

* Tue Jun 28 2022 Antonio Trande <sagitter@fedoraproject.org> - 2.5.0-5
- Exclude pyside2 dependency (rhbz#2098790)

* Thu Feb 10 2022 Orion Poplawski <orion@nwra.com> - 2.5.0-4
- Rebuild for glew 2.2

* Fri Jan 21 2022 Fedora Release Engineering <releng@fedoraproject.org> - 2.5.0-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_36_Mass_Rebuild

* Wed Oct 06 2021 Antonio Trande <sagitter@fedoraproject.org> - 2.5.0-2
- Release 2.5.0 | Upload pymol.png correctly

* Wed Oct 06 2021 Antonio Trande <sagitter@fedoraproject.org> - 2.5.0-1
- Release 2.5.0

* Tue Aug 10 2021 Orion Poplawski <orion@nwra.com> - 2.4.0-8
- Rebuild for netcdf 4.8.0

* Tue Aug 10 2021 Orion Poplawski <orion@nwra.com> - 2.4.0-7
- Rebuild for netcdf 4.8.0

* Fri Jul 23 2021 Fedora Release Engineering <releng@fedoraproject.org> - 2.4.0-6
- Rebuilt for https://fedoraproject.org/wiki/Fedora_35_Mass_Rebuild

* Fri Jun 04 2021 Python Maint <python-maint@redhat.com> - 2.4.0-5
- Rebuilt for Python 3.10

* Wed Jan 27 2021 Fedora Release Engineering <releng@fedoraproject.org> - 2.4.0-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_34_Mass_Rebuild

* Wed Jul 29 2020 sagitter <sagitter@fedoraproject.org> - 2.4.0-3
- Fix for upstream bug #119 (rhbz#1861558)

* Tue Jul 28 2020 Fedora Release Engineering <releng@fedoraproject.org> - 2.4.0-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_33_Mass_Rebuild

* Thu Jun 18 2020 sagitter <sagitter@fedoraproject.org> - 2.4.0-1
- Release 2.4.0

* Tue Jun 16 2020 sagitter <sagitter@fedoraproject.org> - 2.3.0-8
- Patched for using Qt interface (rhbz#1794874)

* Tue May 26 2020 Miro Hrončok <miro@hroncok.cz> - 2.3.0-7
- Rebuilt for Python 3.9

* Thu Jan 30 2020 Fedora Release Engineering <releng@fedoraproject.org> - 2.3.0-6
- Rebuilt for https://fedoraproject.org/wiki/Fedora_32_Mass_Rebuild

* Wed Jan 22 2020 sagitter <sagitter@fedoraproject.org> - 2.3.0-5
- Fix if condition

* Wed Jan 22 2020 sagitter <sagitter@fedoraproject.org> - 2.3.0-4
- Patched for Python 3.9

* Thu Jan 16 2020 sagitter <sagitter@fedoraproject.org> - 2.3.0-3
- Fix default flags for g++

* Thu Jan 02 2020 sagitter <sagitter@fedoraproject.org> - 2.3.0-2
- Fix Changelog

* Thu Jan 02 2020 sagitter <sagitter@fedoraproject.org> - 2.3.0-1
- Release 2.3.0

* Thu Jan 02 2020 Tomas Hrcka <thrcka@redhat.com> - 2.1.0-12
- Revert "pymol fails to build from source:
  https://bugzilla.redhat.com/show_bug.cgi?id=1675704"

* Fri Jul 26 2019 Fedora Release Engineering <releng@fedoraproject.org> - 2.1.0-11
- Rebuilt for https://fedoraproject.org/wiki/Fedora_31_Mass_Rebuild

* Sat Feb 02 2019 Fedora Release Engineering <releng@fedoraproject.org> - 2.1.0-10
- Rebuilt for https://fedoraproject.org/wiki/Fedora_30_Mass_Rebuild

* Tue Jan 29 2019 Igor Gnatenko <ignatenkobrain@fedoraproject.org> - 2.1.0-9
- Remove obsolete scriptlets

* Mon Jan 28 2019 Igor Gnatenko <ignatenkobrain@fedoraproject.org> - 2.1.0-8
- Remove obsolete Group tag

* Thu Aug 23 2018 Nicolas Chauvet <kwizart@gmail.com> - 2.1.0-7
- Rebuilt for glew 2.1.0

* Mon Aug 06 2018 Dan Horák <dan@danny.cz> - 2.1.0-6
- workaround FTBFS (#1605559)

* Tue Jul 24 2018 Miro Hrončok <miro@hroncok.cz> - 2.1.0-5
- BR gcc-c++

* Fri Jul 13 2018 Fedora Release Engineering <releng@fedoraproject.org> - 2.1.0-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_29_Mass_Rebuild

* Tue Jul 10 2018 Jason Tibbitts <tibbs@math.uh.edu> - 2.1.0-3
- Remove needless use of %%defattr

* Tue Jun 19 2018 Miro Hrončok <miro@hroncok.cz> - 2.1.0-2
- Rebuilt for Python 3.7

* Fri Mar 23 2018 Tim Fenn <tfenn@localhost.localdomain> - 2.1.0-1
- update to 2.1.0; switch to PyQt UI

* Tue Feb 27 2018 Tim Fenn <tfenn@localhost.localdomain> - 1.9.0-1
- update to 1.9.0, includes fix for BZ 1539225

* Wed Feb 14 2018 Igor Gnatenko <ignatenkobrain@fedoraproject.org> - 1.8.6-6
- Remove %%clean section

* Fri Feb 09 2018 Fedora Release Engineering <releng@fedoraproject.org> - 1.8.6-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_28_Mass_Rebuild

* Tue Dec 12 2017 Tim Fenn <tfenn@localhost.localdomain> - 1.8.6-4
- patch for BZ 1359812

* Thu Aug 03 2017 Fedora Release Engineering <releng@fedoraproject.org> - 1.8.6-3
- Rebuilt for
  https://fedoraproject.org/wiki/Fedora_27_Binutils_Mass_Rebuild

* Thu Jul 27 2017 Fedora Release Engineering <releng@fedoraproject.org> - 1.8.6-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Mass_Rebuild

* Sat Mar 18 2017 Tim Fenn <tim.fenn@gmail.com> - 1.8.6-1
- update to 1.8.6

* Sat Feb 11 2017 Fedora Release Engineering <releng@fedoraproject.org> - 1.8.4-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_26_Mass_Rebuild

* Tue Jan 10 2017 Orion Poplawski <orion@cora.nwra.com> - 1.8.4-3
- Rebuild for glew 2.0.0

* Thu Dec 22 2016 Miro Hrončok <miro@hroncok.cz> - 1.8.4-2
- Rebuild for Python 3.6

* Fri Oct 14 2016 Tim Fenn <tim.fenn@gmail.com> - 1.8.4-1
- update to 1.8.4

* Thu Sep 01 2016 Tim Fenn <tim.fenn@gmail.com> - 1.8.2.2-6
- add python3-tkinter requires (BZ 1368810)

* Sat Jul 30 2016 Tim Fenn <tfenn@localhost.localdomain> - 1.8.2.2-5
- fix for python requires (BZ 1359812)

* Sat Jul 30 2016 Tim Fenn <tfenn@localhost.localdomain> - 1.8.2.2-4
- fix for python requires (BZ 1359812)

* Tue Jul 19 2016 Fedora Release Engineering <releng@fedoraproject.org> - 1.8.2.2-3
- https://fedoraproject.org/wiki/Changes/Automatic_Provides_for_Python_RPM_
  Packages

* Sat Jul 16 2016 Tim Fenn <tim.fenn@gmail.com> - 1.8.2.2-2
- fix to pmw requires (BZ 1357051)

* Sun Jun 26 2016 Tim Fenn <tim.fenn@gmail.com> - 1.8.2.2-1
- update to 1.8.2.2
- update to python3

* Sun Mar 13 2016 Tim Fenn <tim.fenn@gmail.com> - 1.8-4
- add WM_CLASS patches (BZ 1311626)

* Thu Feb 04 2016 Fedora Release Engineering <releng@fedoraproject.org> - 1.8-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Thu Jan 14 2016 Adam Jackson <ajax@redhat.com> - 1.8-2
- Rebuild for glew 1.13

* Wed Dec 09 2015 Tim Fenn <tim.fenn@gmail.com> - 1.8-1
- update to 1.8

* Mon Jun 29 2015 Tim Fenn <tim.fenn@gmail.com> - 1.7.6-1
- update to 1.7.6 (SVN 4121)
- add appdata.xml

* Thu Jun 18 2015 Dennis Gilmore <dennis@ausil.us> - 1.7.4-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Sat May 02 2015 Kalev Lember <kalevlember@gmail.com> - 1.7.4-2
- Rebuilt for GCC 5 C++11 ABI change

* Sun Dec 07 2014 Tim Fenn <tim.fenn@gmail.com> - 1.7.4-1
- update to 1.7.4 (SVN 4104)

* Mon Sep 22 2014 Tim Fenn <tim.fenn@gmail.com> - 1.7.2-2
- RPMAUTOSPEC: unresolvable merge
## END: Generated by rpmautospec
